@@ -1,6 +1,6 @@
 package RPi::MultiPCA9685;
 use 5.006;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our @ISA = qw();
 use strict;
 use warnings;
@@ -48,7 +48,7 @@ sub setChannelPWM {
   my $splitref=\@split;                    # RPI::I2C needs all moves in an array reference	    
   my $brd=int($servo*2/32);                # calc the board number - the pwm board to write to
   my $obrd=$brd;                           # previous board is identical with current     	  
-  while ($i <= $numref){                   # $i points onto array element of input array (2 elements per servo)
+  while ($i < $numref){                    # $i points onto array element of input array (2 elements per servo)
     $brd=int(($i+$servo*2)/32);            # calc the board number     	  
     if ($rc > 15) {
       $dev[$obrd]->write_block($splitref,$startreg); # pass all moves of the first block to the PCA9685 chip 
